/**
 * Floating window controller
 *
 * @class
 * @since 3.0.0
 *
 * @param {$scope}              $scope              Floating window scope
 * @param {ApplicationContext}  ApplicationContext  Service to retrieve Zeedhi services
 * @param {Query}               Query               Service to build queries
 * @param {ScreenService}       ScreenService       Service to handle screen
 * @param {metaDataFactory}     metaDataFactory     Service to factory models from metadata
 */
var ZhLayoutFloatingCardController = function($scope, ApplicationContext, Query, ScreenService, metaDataFactory){

    var widget = $scope.widget;
    $scope.appliedPreference = null;

    var ZhLayoutPreferences = ApplicationContext.ZhLayoutPreferences;
    var ZhPreferences = ApplicationContext.ZhPreferences;
    var ZhLayoutConfigController = ApplicationContext.ZhLayoutConfigController;

    var fieldDefaultProperties = {
        isVisible: true,
        showOnList: true,
        visibility: true,
        grouped: false,
        fixed: false
    };

    var dataSource = metaDataFactory.factoryDataSource({
        'name': 'zh-layout-preferences#/layout',
        'localStorage': false,
        'lazyLoad': true,
        'rest': true,
        'data': []
    });

    dataSource.afterLoadDataSource(function(){
        return ZhLayoutPreferences.addIsDefaultLayoutToLayouts(dataSource.data, widget.id).then(function(layouts){
            dataSource.data = layouts;
        });
    });

    $scope.customizationCard = {
        'label': 'Layouts',
        'type': 'layout',
        'openLayoutConfiguration': openLayoutConfiguration,
        'refreshLayouts': refreshLayouts,
        'applyOriginalLayout': applyOriginalLayout,
        'applyLayout': applyPreference,
        'dataSource': dataSource
    };

    ZhLayoutPreferences.registerLayoutDataSource(widget.id, $scope.customizationCard.dataSource);

    widget.setAppliedLayout = setAppliedLayout;

    $scope.$on('$destroy', function() {
        delete dataSource.afterLoadDataSourcelistener;
    });

    function setAppliedLayout(layout){
        $scope.appliedPreference = layout;
        widget.appliedLayout = layout;
    }

    function openLayoutConfiguration(){
        var dataSource = $scope.customizationCard.dataSource;
        return ZhLayoutConfigController.getConfigWidget(widget, dataSource).then(function(configWidget){
            return ScreenService.openPopup(configWidget);
        });
    }

    function refreshLayouts(){
        return ZhPreferences.getUserID().then(function(){
            var query = Query.build()
                .where('WIDGET_ID').equals(widget.id);

            return $scope.customizationCard.dataSource.load(query.where());
        });
    }

    function applyOriginalLayout(){
        return ZhLayoutPreferences.applyOriginalLayout(widget);
    }

    function applyPreference(layout){
        return ZhLayoutPreferences.applyLayout(widget, layout);
    }

    function applyDefaultLayout(){
        ZhPreferences.getDefaultWidgetPreferences(widget.id).then(function(defaultPreference){
            if(defaultPreference.defaultLayout){
                applyPreference(defaultPreference.defaultLayout);
            } else {
                applyOriginalLayout();
            }
        });
    }

    (function initLayoutPreferences(){
        if(ZhPreferences.validateWidget(widget)){
            if(Util.isUndefinedOrNull(widget.appliedLayout)){
                applyDefaultLayout();
            } else {
                applyPreference(widget.appliedLayout);
            }
        }
    })();

};

ZeedhiController.controller('ZhLayoutFloatingCardController', ZhLayoutFloatingCardController);